 /* 
 * $Id: ModuleContainerImpl.java 3875 2012-05-31 14:42:20Z mitcje $
 * $URL: https://open.jira.com/svn/IKASAN/tags/ikasan-module-0.9.0-RC1/src/main/java/org/ikasan/module/container/ModuleContainerImpl.java $
 *
 * ====================================================================
 * Ikasan Enterprise Integration Platform
 * 
 * Distributed under the Modified BSD License.
 * Copyright notice: The copyright for this software and a full listing 
 * of individual contributors are as shown in the packaged copyright.txt 
 * file. 
 * 
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution.
 *
 *  - Neither the name of the ORGANIZATION nor the names of its contributors may
 *    be used to endorse or promote products derived from this software without 
 *    specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE 
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE 
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ====================================================================
 */
package org.ikasan.module.container;

import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

import org.ikasan.spec.module.Module;
import org.ikasan.spec.module.ModuleContainer;

/**
 * Default implementation for Module Container 
 * 
 * @author Ikasan Development Team
 */
public class ModuleContainerImpl implements ModuleContainer
{

    /** Map of all loaded modules */
    protected Map<String, Module> modules = new LinkedHashMap<String, Module>();

    /**
     * Exposes all the loaded <code>Module</code>s
     * 
     * @return List of all loaded <code>Module</code>s
     */
    public List<Module> getModules()
    {
        return new ArrayList<Module>(this.modules.values());
    }

    /**
     * Returns a module by name
     * 
     * @param moduleName - The name of the module to get
     * @return Module
     */
    public Module getModule(String moduleName)
    {
        return this.modules.get(moduleName);
    }

    public void add(Module module)
    {
        this.modules.put(module.getName(), module);
        
    }
}
